@@ -17,8 +17,9 @@ from vectorcode.cli_utils import (
     expand_path,
 )
 from vectorcode.common import (
-    get_client,
+    ClientManager,
     get_collection,
+    get_embedding_function,
     verify_ef,
 )
 from vectorcode.subcommands.query.reranker import (
@@ -67,7 +68,7 @@ async def get_query_result_files(
                 )
                 logger.info(f"Querying {num_query} chunks for reranking.")
         results = await collection.query(
-            query_texts=query_chunks,
+            query_embeddings=get_embedding_function(configs)(query_chunks),
             n_results=num_query,
             include=[
                 IncludeEnum.metadatas,
@@ -114,7 +115,10 @@ async def build_query_results(
                 assert chunk_texts is not None, (
                     "QueryResult does not contain `documents`!"
                 )
-                full_result: dict[str, str | int] = {"chunk": str(chunk_texts[0])}
+                full_result: dict[str, str | int] = {
+                    "chunk": str(chunk_texts[0]),
+                    "chunk_id": identifier,
+                }
                 if meta[0].get("start") is not None and meta[0].get("end") is not None:
                     path = str(meta[0].get("path"))
                     with open(path) as fin:
@@ -157,52 +161,52 @@ async def query(configs: Config) -> int:
             "Having both chunk and document in the output is not supported!",
         )
         return 1
-    client = await get_client(configs)
-    try:
-        collection = await get_collection(client, configs, False)
-        if not verify_ef(collection, configs):
-            return 1
-    except (ValueError, InvalidCollectionException) as e:
-        logger.error(
-            f"{e.__class__.__name__}: There's no existing collection for {configs.project_root}",
-        )
-        return 1
-    except InvalidDimensionException as e:
-        logger.error(
-            f"{e.__class__.__name__}: The collection was embedded with a different embedding model.",
-        )
-        return 1
-    except IndexError as e:  # pragma: nocover
-        logger.error(
-            f"{e.__class__.__name__}: Failed to get the collection. Please check your config."
-        )
-        return 1
-
-    if not configs.pipe:
-        print("Starting querying...")
-
-    if QueryInclude.chunk in configs.include:
-        if len((await collection.get(where={"start": {"$gte": 0}}))["ids"]) == 0:
-            logger.warning(
-                """
-This collection doesn't contain line range metadata. Falling back to `--include path document`. 
-Please re-vectorise it to use `--include chunk`.""",
+    async with ClientManager().get_client(configs) as client:
+        try:
+            collection = await get_collection(client, configs, False)
+            if not verify_ef(collection, configs):
+                return 1
+        except (ValueError, InvalidCollectionException) as e:
+            logger.error(
+                f"{e.__class__.__name__}: There's no existing collection for {configs.project_root}",
             )
-            configs.include = [QueryInclude.path, QueryInclude.document]
+            return 1
+        except InvalidDimensionException as e:
+            logger.error(
+                f"{e.__class__.__name__}: The collection was embedded with a different embedding model.",
+            )
+            return 1
+        except IndexError as e:  # pragma: nocover
+            logger.error(
+                f"{e.__class__.__name__}: Failed to get the collection. Please check your config."
+            )
+            return 1
 
-    try:
-        structured_result = await build_query_results(collection, configs)
-    except RerankerError as e:  # pragma: nocover
-        # error logs should be handled where they're raised
-        logger.error(f"{e.__class__.__name__}")
-        return 1
+        if not configs.pipe:
+            print("Starting querying...")
 
-    if configs.pipe:
-        print(json.dumps(structured_result))
-    else:
-        for idx, result in enumerate(structured_result):
-            for include_item in configs.include:
-                print(f"{include_item.to_header()}{result.get(include_item.value)}")
-            if idx != len(structured_result) - 1:
-                print()
-    return 0
+        if QueryInclude.chunk in configs.include:
+            if len((await collection.get(where={"start": {"$gte": 0}}))["ids"]) == 0:
+                logger.warning(
+                    """
+    This collection doesn't contain line range metadata. Falling back to `--include path document`. 
+    Please re-vectorise it to use `--include chunk`.""",
+                )
+                configs.include = [QueryInclude.path, QueryInclude.document]
+
+        try:
+            structured_result = await build_query_results(collection, configs)
+        except RerankerError as e:  # pragma: nocover
+            # error logs should be handled where they're raised
+            logger.error(f"{e.__class__.__name__}")
+            return 1
+
+        if configs.pipe:
+            print(json.dumps(structured_result))
+        else:
+            for idx, result in enumerate(structured_result):
+                for include_item in configs.include:
+                    print(f"{include_item.to_header()}{result.get(include_item.value)}")
+                if idx != len(structured_result) - 1:
+                    print()
+        return 0
